@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: March 2012 */
 
 
 /* This file contains debugging functions. */
@@ -37,7 +37,8 @@ static char *accstrings[] = {
 static char *ornstrings[] = {
   "fermata", "trill", "trill+sharp", "trill+flat", "trill+natural",
   "tremolo1", "tremolo2", "tremolo3", "mordent", "double mordent",
-  "inverted mordent", "double inverted mordent", "turn", "arpeggio",
+  "inverted mordent", "double inverted mordent", "turn", 
+  "inverted turn", "arpeggio", "arpeggio + uparrow", "arpeggio + downarrow",
   "spread" };
 
 
