@@ -543,7 +543,7 @@ while (!page_done) switch(page_state)
 
   adjustkeyposition = 0;
   adjusttimeposition = 0;
-
+  
   if (mac_diffstave(page_nextdata->notsuspend, page_accepteddata->notsuspend) ||
       page_nextdata->stavenames != page_accepteddata->stavenames)
     {
@@ -812,7 +812,7 @@ while (!page_done) switch(page_state)
 
       stretchn = curmovt->linelength - xxadjust;
       stretchd = xposition - xxadjust;
-       
+      
       page_sysblock->xjustify = 0;
       page_sysblock->flags |= sysblock_stretch;
 
@@ -860,7 +860,8 @@ while (!page_done) switch(page_state)
         for (j = 1; j <= page_lastwanted; j++)
           page_sysclef[j] = page_sysblock->cont[j].clef; 
            
-        for (page_barnumber = page_sysblock->barstart; page_barnumber <= page_sysblock->barend;
+        for (page_barnumber = page_sysblock->barstart; 
+             page_barnumber <= page_sysblock->barend;
              page_barnumber++)
           {
           barposstr *bp = curmovt->posvector + page_barnumber;
@@ -875,11 +876,13 @@ while (!page_done) switch(page_state)
           xposition += save_xxwidth + curmovt->barlinespace;  /* Unstretched barlinewidth */
         stretchd = xposition - xxadjust;
 
-        /****
-        debug_printf("bars %d-%d old=%d new=%d\n", page_sysblock->barstart, 
-          page_sysblock->barend, mac_muldiv(page_layout_stretchn, 1000, page_layout_stretchd),
-          mac_muldiv(stretchn, 1000, stretchd)); 
-        ****/
+        if (main_tracepos == (-1) || 
+            (page_sysblock->barstart <= main_tracepos &&
+             page_sysblock->barend >= main_tracepos))  
+          debug_printf("i=%d bars %d-%d old=%d new=%d\n", i,
+            page_sysblock->barstart, page_sysblock->barend, 
+              mac_muldiv(page_layout_stretchn, 1000, page_layout_stretchd), 
+                mac_muldiv(stretchn, 1000, stretchd)); 
         }
       }
 
@@ -1193,7 +1196,7 @@ while (!page_done) switch(page_state)
     curpage->spaceleft -= sysdepth + page_sysblock->systemgap;
     page_state = page_state_newsystem;
     page_lastsystem = page_sysblock;
-
+    
     /* Update the vertical justification parameters if they changed in this
     system. */
 
@@ -1249,7 +1252,6 @@ while (!page_done) switch(page_state)
 
     if (page_barnumber > curmovt->barcount) page_state = page_state_donemovt;
     }
-
   break;
 
 
