@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: March 2012 */
 
 /* This is the main header file, imported by all other sources. */
 
@@ -141,7 +141,7 @@ should be one that is always available in the base font, with code less that
 *     Structures used in barhdr.h                *
 *************************************************/
 
-/* We need to define certain structures before including barhdr.h. Other 
+/* We need to define certain structures before including barhdr.h. Other
 structures are defined later, below. */
 
 
@@ -151,7 +151,7 @@ typedef struct {
   int   ident;
   int   rotate;
   int   xdelta;
-  int   ydelta;  
+  int   ydelta;
   uschar *text;
   short int flags;
   short int size;
@@ -167,10 +167,10 @@ typedef struct {
   union {
     void *ptr;
     int   val;
-  } d;   
-} drawitem;    
+  } d;
+} drawitem;
 
-/* Types of value in draw programs, stacks, and variables; used in the dtype 
+/* Types of value in draw programs, stacks, and variables; used in the dtype
 field in the structure above for items on the stack and for variables. */
 
 #define dd_any      1      /* Used in the checklist for any type allowed */
@@ -365,6 +365,8 @@ accidental on the relevant line or space. */
 *              Global procedure macros           *
 *************************************************/
 
+#define ROUND(x) ((((x) + sizeof(void *) - 1)/sizeof(void *)) * sizeof(void *))
+
 #define mac_fdiv(f,d) ((int)(((double)(f) * 1000.0)/((double) (d))))
 
 #define mac_muldiv(a,b,c) \
@@ -374,8 +376,9 @@ accidental on the relevant line or space. */
   main_stavemagn = (curmovt->stavesizes)[i]
 
 #define mac_advancechord(ww) \
-  if ((++ww)->type == b_Jump) \
-    ww = (b_notestr *)((b_Jumpstr *)(((b_Jumpstr *)ww)->next) + 1)
+  if ((ww = (b_notestr *)((uschar *)ww + length_table[b_note]))->type == b_Jump) \
+    ww = (b_notestr *) \
+      ((uschar *)(((b_Jumpstr *)ww)->next) + length_table[b_Jump])
 
 #define mac_couplepitch(p, f) \
   if ((f & (nf_coupleU | nf_coupleD)) != 0) \
@@ -523,7 +526,7 @@ typedef struct kerntablestr {
 typedef struct {
   uschar *psname;                 /* PostScript font name */
   int *widths;                    /* Pointer to basic width table */
-  int *r2ladjusts;                /* Pointer to right-to-left adjusts */ 
+  int *r2ladjusts;                /* Pointer to right-to-left adjusts */
   int *heights;                   /* Pointer to height table, if any */
   int kerncount;                  /* Size of kern table */
   tree_node *high_tree;           /* Tree for data for high val chars */
@@ -639,9 +642,9 @@ typedef struct ptimestr {
 typedef struct pkeystr {
   struct pkeystr *next;
   int key;
-  int clef; 
+  int clef;
   uschar *string;
-} pkeystr;      
+} pkeystr;
 
 /* One transposed key masquerade item */
 
@@ -816,8 +819,8 @@ typedef struct {
   int   footnotesep;
   int   gracespacing[2];
   int   gracestyle;
-  int   hflatstyle; 
-  int   hsharpstyle; 
+  int   hflatstyle;
+  int   hsharpstyle;
   int   hairpinlinewidth;
   int   hairpinwidth;
   int   hyphenthreshold;
@@ -825,7 +828,7 @@ typedef struct {
   int   key;
   int   keyspacing;
   int   laststave;
-  int   ledger; 
+  int   ledger;
   int   leftmargin;
   int   linelength;
   int   maxbarcount;
@@ -1117,6 +1120,8 @@ extern int      curstave;              /* Current stave number */
 extern uschar *arg_from_name;          /* Name on command line */
 extern uschar *arg_to_name;            /* Name on command line */
 
+extern BOOL bar_use_draw;              /* Use direct drawing for bar lines */
+
 extern uschar *copyright;
 
 extern FILE *debug_file;
@@ -1258,6 +1263,7 @@ extern stavestr **stavetable;          /* Points to pointers to stave struct */
 
 extern int  stave_bottoms[];           /* Levels of top/bottom lines of staves */
 extern int  stave_tops[];
+extern BOOL stave_use_draw;            /* Use direct drawing for staves */
 extern BOOL stave_use_widechars;       /* Use 100-pt chars for staves */
 
 extern const int     utf8_table1[];    /* Various tables for UTF-8 processing */
