@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2008 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: September 2008 */
+/* This file last modified: March 2012 */
 
 
 /* This file contains code for setting up and outputting beams */
@@ -555,10 +555,10 @@ for (level = throughlevel+1; level <= 4; level++)
   do mac_advancechord(postleft); while (postleft->type == b_chord);
   if (postleft->type == b_tie)
     {
-    postleft = (b_notestr *)((uschar *)postleft + sizeof(b_tiestr));
+    postleft = (b_notestr *)((uschar *)postleft + length_table[b_tie]);
     if (postleft->type == b_Jump)
-      postleft =
-        (b_notestr *)((b_Jumpstr *)(((b_Jumpstr *)postleft)->next)+1);
+      postleft = (b_notestr *)
+        ((uschar *)(((b_Jumpstr *)postleft)->next) + length_table[b_Jump]);
     }
   firstbreak2 = (postleft->type == b_beambreak2);
 
@@ -599,10 +599,10 @@ for (level = throughlevel+1; level <= 4; level++)
     do mac_advancechord(postright); while (postright->type == b_chord);
     if (postright->type == b_tie)
       {
-      postright = (b_notestr *)((uschar *)postright + sizeof(b_tiestr));
+      postright = (b_notestr *)((uschar *)postright + length_table[b_tie]);
       if (postright->type == b_Jump)
-        postright =
-          (b_notestr *)((b_Jumpstr *)(((b_Jumpstr *)postright)->next)+1);
+        postright = (b_notestr *)
+          ((uschar *)(((b_Jumpstr *)postright)->next) + length_table[b_Jump]);
       }
     rightbreak2 = (postright->type == b_beambreak2);
 
