@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: March 2012 */
 
 
 /* This file contains the code for generating an image of one individual note
@@ -1248,9 +1248,11 @@ if (n_ornament != NULL)
 
     /* Move on to next ornament, if any */
 
-    while ((++n_ornament)->type == b_Jump)
+    n_ornament = (b_ornamentstr *)
+      ((uschar *)n_ornament + length_table[b_ornament]);
+    if (n_ornament->type == b_Jump)
       n_ornament = (b_ornamentstr *)
-        ((b_Jumpstr *)(((b_Jumpstr *)n_ornament)->next) + 1);
+        ((uschar *)(((b_Jumpstr *)n_ornament)->next) + length_table[b_Jump]);
 
     if (n_ornament->type != b_ornament) break;
     }
