@@ -2,10 +2,10 @@
 *    The PMW Music Typesetter - 3rd incarnation  *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 1991 - 2010 */
+/* Copyright (c) Philip Hazel, 1991 - 2012 */
 
 /* Written by Philip Hazel, starting November 1991 */
-/* This file last modified: December 2010 */
+/* This file last modified: March 2012 */
 
 
 /* This file contains all the major tables used by the program; a few that are
@@ -708,8 +708,6 @@ of structures. The lengths are rounded up to a whole number of pointers. On the
 Acorn, using Norcroft C, this was done by by the sizeof() operator, but it
 seems not to be the case with gcc. */
 
-#define ROUND(x) ((((x) + sizeof(void *) - 1)/sizeof(void *)) * sizeof(void *))
-
 uschar length_table [] = {
   ROUND(sizeof(b_Endstr)),
   ROUND(sizeof(b_Jumpstr)),
@@ -767,9 +765,9 @@ uschar length_table [] = {
   ROUND(sizeof(b_resetstr)),
   ROUND(sizeof(b_resumestr)),
   ROUND(sizeof(b_rrepeatstr)),
-  ROUND(sizeof(b_setclef)),
-  ROUND(sizeof(b_setkey)),
-  ROUND(sizeof(b_settime)),
+  ROUND(sizeof(b_setclefstr)),
+  ROUND(sizeof(b_setkeystr)),
+  ROUND(sizeof(b_settimestr)),
   ROUND(sizeof(b_sgstr)),
   ROUND(sizeof(b_sgstr)),
   ROUND(sizeof(b_slopestr)),
